/**
  *  \file client/tiles/fleetheader.cc
  *  \brief Fleet Screen Header Tile
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/fleetheader.h"
#include "game/ship.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "game/global.h"
#include "resmgr/resid.h"

WFleetScreenHeaderTile::WFleetScreenHeaderTile(GObjectSelection& selection)
    : WControlScreenHeaderTile(selection, bName + bAdd + bJoin, IntExecutionContext::pkDefault)
{ }

string_t
WFleetScreenHeaderTile::getTitle()
{
    GShip* sh = dynamic_cast<GShip*>(getCurrentObject());
    if (sh != 0 && sh->getFleetNumber() != 0) {
        const int fid = sh->getFleetNumber();
        string_t result = format(_("Fleet %d"), fid);
        GShip& leader = getDisplayedTurn().getCurrentUniverse().getShip(fid);
        if (!leader.getFleetName().empty()) {
            result += ": ";
            result += leader.getFleetName();
        }
        return result;
    } else {
        return string_t();
    }
}

string_t
WFleetScreenHeaderTile::getSubtitle()
{
    GShip* sh = dynamic_cast<GShip*>(getCurrentObject());
    int num = 0;
    if (sh != 0 && sh->getFleetNumber() != 0) {
        const int fid = sh->getFleetNumber();
        GUniverse& univ = getDisplayedTurn().getCurrentUniverse();
        for (int i = 1; i <= NUM_SHIPS; ++i) {
            if (univ.getShip(i).getFleetNumber() == fid) {
                ++num;
            }
        }
    }
    return format(_("(%d ship%!1{s%})"), num);
}

ResId
WFleetScreenHeaderTile::getPictureId()
{
    if (GShip* sh = dynamic_cast<GShip*>(getCurrentObject())) {
        return ResId(res::ship, sh->getHull().getInternalPictureNumber(), sh->getHullId());
    } else {
        return ResId();
    }
}

int
WFleetScreenHeaderTile::getNumMessages()
{
    return 0;
}
