/**
  *  \file int/if/drawingif.h
  *  \brief Interpreter Game Interface: Drawings
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_DRAWINGIF_H
#define PCC_V2_INT_IF_DRAWINGIF_H

#include "int/context.h"
#include "game/drawing.h"

IntContext* IFDrawingMake();

/** Drawing context. */
class IntDrawingContext : public IntContext {
 public:
    IntDrawingContext(GDrawingContainer& drawings);
    ~IntDrawingContext();

    // IntContext:
    int32_t   lookup(const IntNameQuery& name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
    GObject*  getObject();
    string_t  toString(bool readable);
    void      store(IntTagNode& sv, Stream& aux);
    void      enumProperties(IntPropertyAcceptor& acceptor);

 private:
    GDrawingContainer& drawings;
    GDrawingContainer::iterator current;
};

/** Drawing property identifier. */
enum IntDrawingProperty {
    idpColor,
    idpComment,
    idpEndX,
    idpEndY,
    idpExpire,
    idpLocX,
    idpLocY,
    idpRadius,
    idpShape,
    idpTag,
    idpTypeString,
    idpTypeCode
};

IntValue* getDrawingProperty(const GDrawing& d, IntDrawingProperty idp);
void      setDrawingProperty(GDrawing& d, IntDrawingProperty idp, IntValue* value);

#endif
